@@ -31,7 +31,7 @@ K_PLUGIN_FACTORY_WITH_JSON(DeviceAutomounterKCMFactory, "device_automounter_kcm.
 
 DeviceAutomounterKCM::DeviceAutomounterKCM(QObject *parent, const KPluginMetaData &data)
     : KCModule(parent, data)
-    , m_settings(new AutomounterSettings(widget()))
+    , m_settings(new AutomounterSettings(this))
     , m_devices(new DeviceModel(m_settings, this))
 {
     setupUi(widget());
